/*!
 * \file 
 * \brief Rs485Isolator Click example
 * 
 * # Description
 * This demo example shows RS485 communication using RS485 Isolator click.
 *
 * The demo application is composed of two sections :
 *
 * ## Application Init
 * Configuring clicks and log objects.
 *
 * ## Application Task
 * Depending on the selected application mode:
 *  - DEMO_APP_TRANSMITER - Prints "MikroE" message to UART
 *  - DEMO_APP_RECEIVER - Reads data from uart and prints to LOG (Default)
 * 
 * \author Katarina Perendic
 *
 */
// ------------------------------------------------------------------- INCLUDES

#include "board.h"
#include "log.h"
#include "rs485isolator.h"

// ------------------------------------------------------------------ VARIABLES

#define DEMO_APP_RECEIVER
//#define DEMO_APP_TRANSMITER

static rs485isolator_t rs485isolator;
static log_t logger;

static rs485isolator_data_t demo_message[ 9 ] = { 'M', 'i', 'k', 'r', 'o', 'E', 13, 10, 0 };

// ------------------------------------------------------ APPLICATION FUNCTIONS

void application_init ( void )
{
    log_cfg_t log_cfg;
    rs485isolator_cfg_t cfg;

    //  Logger initialization.

    log_cfg.level = LOG_LEVEL_DEBUG;
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info( &logger, "---- Application Init ----" );

    //  Click initialization.

    rs485isolator_cfg_setup( &cfg );
    RS485ISOLATOR_MAP_MIKROBUS( cfg, MIKROBUS_1 );
    rs485isolator_init( &rs485isolator, &cfg );
}

void application_task ( void )
{
    char tmp;
    
    //  Task implementation.
    
#ifdef DEMO_APP_RECEIVER

       // RECEIVER - UART polling

       tmp = rs485isolator_generic_single_read( &rs485isolator );
       log_printf( &logger, "%c", tmp );
#endif
#ifdef DEMO_APP_TRANSMITER

       // TRANSMITER - TX each 2 sec
       
       rs485isolator_generic_multi_write( &rs485isolator, demo_message, 9 );
       Delay_ms( 2000 );
#endif

}

void main ( void )
{
    application_init( );

    for ( ; ; )
    {
        application_task( );
    }
}


// ------------------------------------------------------------------------ END
