
 

---
# RS485 Isolator click

RS485 Isolator click is an RS485 communication isolator and carries the ADM2682EBRIZ, a 5 kV rms signal and power isolated RS-485 transceiver.

<p align="center">
  <img src="https://download.mikroe.com/images/click_for_ide/RS485-Isolator.png">
</p>

[click Product page](<https://www.mikroe.com/rs485-isolator-click>)

---

#### Click library 

- **Author**        : Katarina Perendic
- **Date**          : nov 2019.
- **Type**          : UART type


# Software Support

We provide a library for the Rs485Isolator Click 
as well as a demo application (example), developed using MikroElektronika 
[compilers](http://shop.mikroe.com/compilers). 
The demo can run on all the main MikroElektronika [development boards](http://shop.mikroe.com/development-boards).

Package can be downloaded/installed directly form compilers IDE(recommended way), or downloaded from our LibStock, or found on mikroE github account. 

## Library Description

> This library contains API for Rs485Isolator Click driver.

#### Standard key functions :

- Config Object Initialization function.
> void rs485isolator_cfg_setup ( rs485isolator_cfg_t *cfg ); 
 
- Initialization function.
> RS485ISOLATOR_RETVAL rs485isolator_init ( rs485isolator_t *ctx, rs485isolator_cfg_t *cfg );

#### Example key functions :

- Set driver state
> void rs485isolator_set_driver_mode ( rs485isolator_t *ctx, uint8_t state );
 
- Set receiver state
> void rs485isolator_set_receiver_mode ( rs485isolator_t *ctx, uint8_t state );

- Generic single read function
> rs485isolator_data_t rs485isolator_generic_single_read ( rs485isolator_t *ctx );

## Examples Description

> This demo example shows RS485 communication using RS485 Isolator click.

**The demo application is composed of two sections :**

### Application Init 

> Configuring clicks and log objects.

```c
void application_init ( void )
{
    log_cfg_t log_cfg;
    rs485isolator_cfg_t cfg;

    //  Logger initialization.

    log_cfg.level = LOG_LEVEL_DEBUG;
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    /log_info( &logger, "---- Application Init ----" );

    //  Click initialization.

    rs485isolator_cfg_setup( &cfg );
    RS485ISOLATOR_MAP_MIKROBUS( cfg, MIKROBUS_1 );
    rs485isolator_init( &rs485isolator, &cfg );
}  
```

### Application Task

> Depending on the selected application mode:
>  - DEMO_APP_TRANSMITER - Prints "MikroE" message to UART
>  - DEMO_APP_RECEIVER - Reads data from uart and prints to LOG (Default)

```c
void application_task ( void )
{
    char tmp;
    
    //  Task implementation.
    
#ifdef DEMO_APP_RECEIVER

       // RECEIVER - UART polling

       tmp = rs485isolator_generic_single_read( &rs485isolator );
       log_printf( &logger, "%c", tmp );
#endif
#ifdef DEMO_APP_TRANSMITER

       // TRANSMITER - TX each 2 sec
       
       rs485isolator_generic_multi_write( &rs485isolator, demo_message, 9 );
       Delay_ms( 2000 );
#endif
}
```

The full application code, and ready to use projects can be  installed directly form compilers IDE(recommneded) or found on LibStock page or mikroE GitHub accaunt.

**Other mikroE Libraries used in the example:** 

- MikroSDK.Board
- MikroSDK.Log
- Click.Rs485Isolator

**Additional notes and informations**

Depending on the development board you are using, you may need 
[USB UART click](http://shop.mikroe.com/usb-uart-click), 
[USB UART 2 Click](http://shop.mikroe.com/usb-uart-2-click) or 
[RS232 Click](http://shop.mikroe.com/rs232-click) to connect to your PC, for 
development systems with no UART to USB interface available on the board. The 
terminal available in all Mikroelektronika 
[compilers](http://shop.mikroe.com/compilers), or any other terminal application 
of your choice, can be used to read the message.



---
